<?php
/*******************************************************************************
 *   Delete Install script
 *******************************************************************************
 *   GuppY PHP Script - version 6.0
 *   CeCILL Copyright (C) 2004-2020 by Laurent Duveau
 *   Initiated by Laurent Duveau and Nicolas Alves
 *   Web site = https://www.freeguppy.org/
 *   e-mail   = guppy@freeguppy.org
 *   V6 developed by Lud Bienaimé
 *      with the participation of the GuppY Team
 *******************************************************************************
 *   Latest Changes :
 * v6.00.00 (December 15, 2020) : initial release
 ******************************************************************************/

header('Pragma: no-cache');
define('CHEMIN', '../');
$selskin = 'no_skin';
include CHEMIN.'inc/includes.inc';
include $lng.'-install.inc';
include 'func_install.php';

$form = import('form', 'POST');


if (empty($form)) {
    DisplayHeader();
	echo '
<p style="text-align:center;">
  <a href="Javascript: window.location=\'delete.php?lng='.$lang[0].'\';">
    <img src="'.CHEMIN.'inc/lang/'.$lang[0].'.gif" width="24" height="16" border="0"/>
  </a>
  &nbsp;&nbsp;&nbsp;&nbsp;
  <a href="Javascript: window.location=\'delete.php?lng='.$lang[1].'\';">
    <img src="'.CHEMIN.'inc/lang/'.$lang[1].'.gif" width="24" height="16" border="0"/>
  </a>
</p>';
	DisplayTitre($clean[10], $clean[11].'<br /><br />'.$clean[3]);
	echo '
<form name="instal0" action="delete.php?lng='.$lng.'" method="post">
  <input type="hidden" name="form" value="1"/>
  <div style="text-align:center;">'.SubmitButton($clean[4]).'&nbsp;&nbsp;
    <button type="reset" style="cursor:pointer;" title="'.$clean[0].'" onclick="javascript:history.back();">'.$clean[0].'</button>
  </div>
</form>';
} elseif ($form == '1') {
    DisplayHeader();
	DisplayTitre($clean[12], $clean[13]);
	echo '
<form name="instal1" action="delete.php?lng='.$lng.'" method="post">
  <input type="hidden" name="form" value="2"/>
  <div style="text-align:center;">'.SubmitButton($clean[4]).'&nbsp;&nbsp;
    <button type="reset" style="cursor:pointer;" title="'.$clean[0].'" onclick="window.location=\'install.php?lng='.$lng.'&form=1\';">'.$clean[0].'</button>
  </div>
</form>';
} elseif ($form == '2') {
	if (empty($doing)) {
		DisplayHeader(CHEMIN.'index.php?lng='.$lng);
		EraseInstall();
		DisplayProcess($clean[12], $clean[14], $clean[15]);
	}
} else {
    DisplayHeader('index.php?lng='.$lng);
}

DisplayFooter();
?>